==> gnome-shell-calculate-3.2.2.4.tar.bz2: gnome-shell-calculate-3.2.2.4/extensions/gnome-shell-lockscreen-extension@calculate-linux.org/extension.js <==
// Copyright (C) 2011 Mir Calculate
// Licence: GPLv2+

const St = imports.gi.St;
const Main = imports.ui.main;
const PopupMenu = imports.ui.popupMenu;
const PanelMenu = imports.ui.panelMenu;
const ModalDialog = imports.ui.modalDialog;
const Gio = imports.gi.Gio;
const Gtk = imports.gi.Gtk;
const Lang = imports.lang;
const Clutter = imports.gi.Clutter;
const DBus = imports.dbus;
const ScreenSaver = imports.misc.screenSaver;
const userMenuButton = imports.ui.main.panel._statusArea['userMenu'];
const ExtensionSystem = imports.ui.extensionSystem;


function LockButton() {
    this._init();
}

LockButton.prototype = {
    __proto__: PanelMenu.SystemStatusButton.prototype,

    _init: function() {
        PanelMenu.SystemStatusButton.prototype._init.call(this, 'changes-prevent');
        this._screenSaverProxy = new ScreenSaver.ScreenSaverProxy();
        this.actor.connect('button-release-event',Lang.bind(this,function() {
            Main.overview.hide();
            this._screenSaverProxy.LockRemote();
        }));
        this.menu.open = function() {}
    },
};


function init() {
}

let _indicatorLock;
let changeExtStateId = null;

function enable() {
  _indicatorLock = new LockButton;
  let _children = Main.panel._rightBox.get_children();
  Main.panel._rightBox.insert_actor(_indicatorLock.actor,_children.length-2);
  _indicatorLock.actor.lower(userMenuButton.actor);
  changeExtStateId = ExtensionSystem.connect('extension-state-changed',
                                          Lang.bind(_indicatorLock,function(o,a) {
    this.actor.lower(userMenuButton.actor);
  }));
}

function disable() {
  _indicatorLock.destroy();
  ExtensionSystem.disconnect(changeExtStateId);
}

==> gnome-shell-calculate-3.4.1.1.tar.bz2: gnome-shell-calculate-3.4.1.1/extensions/gnome-shell-lockscreen-extension@calculate-linux.org/extension.js <==
// Copyright (C) 2011 Mir Calculate
// Licence: GPLv2+

const St = imports.gi.St;
const Main = imports.ui.main;
const Meta = imports.gi.Meta;
const PopupMenu = imports.ui.popupMenu;
const PanelMenu = imports.ui.panelMenu;
const ModalDialog = imports.ui.modalDialog;
const Gio = imports.gi.Gio;
const Gtk = imports.gi.Gtk;
const Lang = imports.lang;
const Clutter = imports.gi.Clutter;
const DBus = imports.dbus;
const ScreenSaver = imports.misc.screenSaver;
const userMenuButton = imports.ui.main.panel._statusArea['userMenu'];
const ExtensionSystem = imports.ui.extensionSystem;

const LockButton = new Lang.Class({
    Name : "LockButton.LockButton",
    Extends: PanelMenu.SystemStatusButton,

    _init: function() {
        PanelMenu.SystemStatusButton.prototype._init.call(this, 'changes-prevent');
        this._screenSaverProxy = new ScreenSaver.ScreenSaverProxy();
        this.actor.connect('button-release-event',Lang.bind(this,function() {
            Main.overview.hide();
            this._screenSaverProxy.LockRemote();
        }));
        this.menu.open = function() {}
    },
});


function init() {
}

let _indicatorLock;
let changeExtStateId = null;

function enable() {
  _indicatorLock = new LockButton;
  let _children = Main.panel._rightBox.get_children();
  Main.panel._rightBox.insert_child_at_index(_indicatorLock.actor,_children.length-2);
  _indicatorLock.actor.lower(userMenuButton.actor);
  changeExtStateId = ExtensionSystem.connect('extension-state-changed',
                                          Lang.bind(_indicatorLock,function(o,a) {
    this.actor.lower(userMenuButton.actor);
  }));
  Meta.keybindings_set_custom_handler('set-spew-mark', function() {
      let _screenSaverProxy = new ScreenSaver.ScreenSaverProxy();
      Main.overview.hide();
      _screenSaverProxy.LockRemote();
  });
}

function disable() {
  _indicatorLock.destroy();
  ExtensionSystem.disconnect(changeExtStateId);
}
